@@ -113,7 +113,10 @@ estim_PS <- function(samples, admixMod, method = c("fixed", "lwr.bnd", "cv"),
 	  dist.out = dist.out,
 	  c.n = c.n,
 	  alp.Lwr = alp.Lwr,
-	  n = n)
+	  n = n,
+	  data = samples,
+	  data.name = deparse1(substitute(samples))
+	)
 
 	if (method == "cv"){ ret$cv.out <- out.cv
 	} else { ret$cv.out <- NULL }
@@ -141,8 +144,8 @@ print.estim_PS <- function(x, ...){
   #print(x$call)
   cat("\n")
   if(x$method != "lwr.bnd"){
-    cat(paste("Estimated mixing weight (of the unknown component):" , round(x$estimated_mixing_weights,3)))
-    #cat("\n", paste("The chosen value c_n is", round(x$c.n, 3)), "\n")
+    cat(paste(" Estimated mixing weight (of the unknown component):" , round(x$estimated_mixing_weights,3)))
+    cat("\n", paste("The chosen value c_n is", round(x$c.n, 3)), "\n")
 #    if( !is.null(x$cv.out)){
 #      old_par <- graphics::par()$mfrow
 #      on.exit(graphics::par(old_par))
@@ -154,7 +157,7 @@ print.estim_PS <- function(x, ...){
     plot(x$dist.out)
     print (paste("The  '95%' lower confidence for alp_0 is ", x$alp.Lwr))
   }
-  cat("\n\n")
+  cat("\n")
 }
 
 
